@@ -4,7 +4,7 @@
 
 -- |
 -- Module      : Database.HDBC.Schema.MySQL
--- Copyright   : 2013 Sho KURODA
+-- Copyright   : 2013 Sho KURODA, 2017 Kei Hibiono
 -- License     : BSD3
 --
 -- Maintainer  : krdlab@gmail.com
@@ -36,6 +36,7 @@ import           Database.HDBC.Schema.Driver        ( TypeMap
                                                     , maybeIO
                                                     , hoistMaybe
                                                     , Driver
+                                                    , driverConfig
                                                     , getFieldsWithMap
                                                     , getPrimaryKey
                                                     , emptyDriver
@@ -49,6 +50,7 @@ import           Database.Relational.Schema.MySQL   ( normalizeColumn
 
 import           Database.Relational.Schema.MySQLInfo.Columns (Columns)
 import qualified Database.Relational.Schema.MySQLInfo.Columns as Columns
+import           Database.Relational.Schema.MySQLInfo.Config (config)
 
 
 instance FromSql SqlValue Columns
@@ -106,3 +108,4 @@ driverMySQL :: IConnection conn => Driver conn
 driverMySQL =
     emptyDriver { getFieldsWithMap = getColumns' }
                 { getPrimaryKey    = getPrimaryKey' }
+                { driverConfig     = config }
