@@ -4,7 +4,7 @@
 
 -- |
 -- Module      : Database.HDBC.Schema.PostgreSQL
--- Copyright   : 2013 Kei Hibino
+-- Copyright   : 2013-2017 Kei Hibino
 -- License     : BSD3
 --
 -- Maintainer  : ex8k.hibino@gmail.com
@@ -39,10 +39,11 @@ import Database.Relational.Schema.PostgreSQL
 import Database.Relational.Schema.PgCatalog.PgAttribute (PgAttribute)
 import Database.Relational.Schema.PgCatalog.PgType (PgType)
 import qualified Database.Relational.Schema.PgCatalog.PgType as Type
+import Database.Relational.Schema.PgCatalog.Config (config)
 
 import Database.HDBC.Schema.Driver
   (TypeMap, LogChan, putVerbose, failWith, maybeIO, hoistMaybe,
-   Driver, getFieldsWithMap, getPrimaryKey, emptyDriver)
+   Driver, driverConfig, getFieldsWithMap, getPrimaryKey, emptyDriver)
 
 
 instance FromSql SqlValue PgAttribute
@@ -71,8 +72,7 @@ getPrimaryKey' conn lchan scm' tbl' = do
       tbl = map toLower tbl'
   mayKeyLen <- runQuery' conn primaryKeyLengthQuerySQL (scm, tbl)
   case mayKeyLen of
-    []        -> do
-      putLog lchan   "getPrimaryKey: Primary key not found."
+    []        ->
       return []
     [keyLen]  -> do
       primCols <- runQuery' conn (primaryKeyQuerySQL keyLen) (scm, tbl)
@@ -113,3 +113,4 @@ driverPostgreSQL :: IConnection conn => Driver conn
 driverPostgreSQL =
   emptyDriver { getFieldsWithMap = getColumns' }
               { getPrimaryKey    = getPrimaryKey' }
+              { driverConfig     = config }
